# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet

%global pypiname tox

Name:           python-tox
Version:        3.14.6
Release:        %mkrel 1
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python

# file toxbootstrap.py is licensed under MIT License
License:        GPLv2+ and MIT
URL:            http://codespeak.net/tox
Source0:        http://pypi.python.org/packages/source/t/%{pypiname}/%{pypiname}-%{version}.tar.gz
BuildArch:      noarch

%description
Tox as is a generic virtualenv management and test command line tool you
can use for:

 - checking your package installs correctly with different Python versions
   and interpreters
 - running your tests in each of the environments, configuring your test tool
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing
   boilerplate and merging CI and shell-based testing.

%package -n python3-%{pypiname}
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  python3-py
BuildRequires:  python3-pytest
BuildRequires:  python3-virtualenv
%{?python_provide:%python_provide python3-%{pypiname}}
Requires:	python3-py
Requires:	python3-pluggy
# python3-virtualenv is rhbz#537246
Requires:	python3-virtualenv

%description -n python3-%{pypiname}
Tox as is a generic virtualenv management and test command line tool you
can use for:

 - checking your package installs correctly with different Python versions
   and interpreters
 - running your tests in each of the environments, configuring your test tool
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing
   boilerplate and merging CI and shell-based testing.

%prep
%setup -q -n %{pypiname}-%{version}

# remove bundled egg-info
rm -rf %{pypiname}.egg-info

%build
%py3_build

%install
%py3_install

# if internet connection available, run tests
%if %{with internet}
%check
%{__python3} setup.py test
%endif

%files -n python3-tox
%doc docs/*.rst
%license LICENSE
%{_bindir}/%{pypiname}
%{_bindir}/%{pypiname}-quickstart
%{python3_sitelib}/%{pypiname}
%{python3_sitelib}/%{pypiname}-%{version}-py%{python3_version}.egg-info


%changelog
* Sun Mar 29 2020 wally <wally> 3.14.6-1.mga8
+ Revision: 1562172
- new version 3.14.6

* Sun Feb 16 2020 umeabot <umeabot> 3.14.0-2.mga8
+ Revision: 1530981
- Mageia 8 Mass Rebuild

* Sat Sep 07 2019 wally <wally> 3.14.0-1.mga8
+ Revision: 1438147
- new version 3.14.0
- drop python2 support
- rebuild for python3.8

* Sat Apr 20 2019 wally <wally> 3.9.0-1.mga7
+ Revision: 1393916
- new version 3.9.0

* Mon Jan 07 2019 wally <wally> 3.0.0-0.rc1.3.mga7
+ Revision: 1350664
- rebuild for python3.7

* Fri Sep 21 2018 umeabot <umeabot> 3.0.0-0.rc1.2.mga7
+ Revision: 1290431
- Mageia 7 Mass Rebuild

* Tue Feb 06 2018 guillomovitch <guillomovitch> 3.0.0-0.rc1.1.mga7
+ Revision: 1199387
- new version 3.0.0rc1

* Sat Aug 05 2017 pterjan <pterjan> 2.3.1-3.mga7
+ Revision: 1135667
- Rebuild for python 3.6

* Sun May 15 2016 ngompa <ngompa> 2.3.1-2.mga6
+ Revision: 1015696
- imported package python-tox


* Sat May 14 2016 Neal Gompa <ngompa13@gmail.com> - 2.3.1-2
- Port to Mageia

* Mon Feb 29 2016 Matthias Runge <mrunge@redhat.com> - 2.3.1-1
- update to 2.3.1

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Nov 12 2015 Kalev Lember <klember@redhat.com> - 2.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Tue Aug 25 2015 Matthias Runge <mrunge@redhat.com> - 2.1.1-2
- add requirement: python-pluggy

* Tue Aug 18 2015 Matthias Runge <mrunge@redhat.com> - 2.1.1-1
- update to 2.1.1

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Dec 16 2014 Matthias Runge <mrunge@redhat.com> - 1.8.1-1
- update to 1.8.1

* Wed Aug 13 2014 Matthias Runge <mrunge@redhat.com> - 1.7.1-3
- Fix ConfigError: ConfigError: substitution key 'posargs' not found
  (rhbz#1127961, rhbz#1128562)

* Wed Jul 30 2014 Matthias Runge <mrunge@redhat.com> - 1.7.1-2
- require virtualenv >= 1.11.2 (rhbz#1122603)

* Tue Jul 08 2014 Matthias Runge <mrunge@redhat.com> - 1.7.1-1
- update to 1.7.1 (rhbz#111797)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Sep 24 2013 Matthias Runge <mrunge@redhat.com> - 1.6.1-1
- update to 1.6.1

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 14 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-7
- add requires python-py, python-virtualenv (rhbz#876246)

* Thu Oct 18 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-6
- change license to GPLv2+ and MIT

* Tue Oct 16 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-5
- totally disable python3 support for now

* Fri Oct 12 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-4
- conditionalize checks, as internet connection required, not available on koji

* Thu Oct 11 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-3
- buildrequirement: virtualenv
- disable python3-tests because of missing build-requirement python3-virtualenv

* Wed Oct 10 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-2
- include tests

* Tue Oct 09 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-1
- initial packaging
